unit Rdx;

{
   Intel RDX Header files for an excellent graphics/gaming engine.

   Copyright (c) 1995, 1996, 1997, 1998  Intel Corporation.  All Rights Reserved.

   Converted to Delphi by:       Jason Kaczor
                                 A Couple A Nerds Computer Consulting

                                 ACoupleANerds@compuserve.com
		                 kaczor@shaw.wave.ca
		                 Evenings: (403) 283-5351
		                 Daytime:  (403) 716-4466

   Conversion Date:              04/18/1998

   Last Change:                  04/23/1998

   Conversion Version:           v.0.9

   Notes:                        v.0.9     - Tested only calls for Surfaces, Bitmaps,
                                           Backgrounds, and Sprites.


   }

interface

uses
  Windows;

type
   { *********************************************************************************** }
   { Object management structures }
   { *********************************************************************************** }

   { Standard function return value }
   DINORVAL = LongInt;

   { Standard Pointer types }
   PBool     = ^WordBool;
   PBoolean  = ^Boolean;
   PByte     = ^Byte;
   PWord     = ^Word;
   PShortInt = ^ShortInt;
   PInteger  = ^Integer;
   PLongInt  = ^LongInt;
   PSingle   = ^Single;
   PDouble   = ^Double;
   PPointer  = ^Pointer;
   PHBMP     = ^HBMP;
   PHWND     = ^THandle;

   PRGBTriple              = ^TRGBTriple;
   PRGBQuad                = ^TRGBQuad;

   { Bitmaps }
   HBMP = THandle;
   HSEQ = THandle;
   PHSEQ = HSEQ;
   BMPHeader = record
            dwBufSize: LongInt;
            dwBufStride: LongInt;
          end {HBMPHeader};
   PBMPHeader = ^BMPHeader;

   PBmp = PInteger;

   { For Bitmap preparation }
   Usage = (D2D_BACKGROUND, D2D_SPRITE, D2D_TILE );

   { Group }
   PHGRP = Pointer;

   { Object }
   PHOBJ = Pointer;

   { Bbackgrounds }
   HBKG = PInteger;
   PBkg = PInteger;

   { Sprites }
   HSPR = Pointer;

   { Tiles }
   HTILE = THandle;

   { Grids }
   GrdLocation = record
              mTile: Word;
              nTile: Word;
            end {GridLocation};
   HGRID = THandle;

   { Color type is used in CreateBitmap & CreateSurface }
   ColorType = (RGB_CLUT8,
            RGB_555,
            RGB_565,
            RGB_24,
            RGB_32,
            RGB_ALPHA  );
   PColorType = ^ColorType;

   { GUID's for the Effects/DirectDraw in the Registry  }
   { This is also declared in the Ole2.pas unit, I did  }
   { not want to include that unit for fear of circular }
   { references in your code }
   TGUID = record
        D1: Longint;
        D2: Word;
        D3: Word;
        D4: array[0..7] of Byte;
      end;

   { For bitmaps }
   {Const RGB555(r,g,b) = ( ((WORD)((b) & 0xf8) >> 3) \;
   function |(_1: (WORD): Integer cdecl; }

   {Const RGB565(r,g,b) = ( ((WORD)((b) & 0xf8) >> 3) \;
   function |(_1: (WORD): Integer cdecl; }

   { Objects }
   HOBJ = THandle;

   { Surfaces }
   HSURF = Pointer;

   { Groups }
   HGRP = Pointer;

   { Timers }
   HTIMER = Pointer;
   PHTIMER = Pointer;

   { Effects }
   HFX = Pointer;
   PHFX = Pointer;

   { Events }
   HEVENT = LongInt;

   { COLLISION }
   Collision_Region = record
                   region: TRect;
                   dwRegionID: LongInt;
                 end {Collision_Region};
   PCollision_Region = ^Collision_Region;

   Collision_Data = record
                 dwCDType: LongInt;
                 dwSizeCDBuf: LongInt;
                 pCDBuf: Pointer;
               end {Collision_Data};
   PCollision_Data = ^Collision_Data;

   Collision_Rect_Data = record
                      nRegions: LongInt;
                      pCRArray: PCollision_Region;
                    end {Collision_Rect_Data};
   PCollision_Rect_Data = ^Collision_Rect_Data;

   Collision_Pair = record
                 hobj1: HOBJ;
                 dwRegionID1: LongInt;
                 hobj2: HOBJ;
                 dwRegionID2: LongInt;
               end {Collision_Pair};
   PCollision_Pair = ^Collision_Pair;

   RECTWH = record
            x: LongInt;
            y: LongInt;
            dx: LongInt;
            dy: LongInt;
          end {RECTWH};
   PRECTWH = ^RECTWH;

   { Morphing }
   FixedPoint_S_15_16 = LongInt;

   SMORPH_VALUES = record
                StartX: FixedPoint_S_15_16;
                StartY: FixedPoint_S_15_16;
                DeltaX: FixedPoint_S_15_16;
                DeltaY: FixedPoint_S_15_16;
              end {SMORPH_VALUES};

  {Type SMORPH_PARAMS = record
                wrap: LongInt;
                pSmorphArray: array[1..512] of SMORPH_VALUES;
             end {SMORPH_PARAMS}

  { RENDER_CALLBACK }
  RENDER_CALLBACK_PARAMS_Proc = procedure(hSurf: HSURF; pBits: PByte; lStride: LongInt; pParams: Pointer);

  DDRAW_RENDER_CALLBACK_PARAMS_Proc = procedure(hSurf: HSURF; lpDirectDraw: Pointer; lpDirectDrawSurface: Pointer; pContext: Pointer);

  { Surface / DirectDraw }
  FULL_SCREEN_PARAMS = record
                    dwWidth: LongInt;
                    dwHeight: LongInt;
                    iColorType: COLORTYPE;
                  end {FULL_SCREEN_PARAMS};

  COLORMAP_ENTRY = record
                nRed, nGreen, nBlue, nIndex: BYTE;
              end {COLORMAP_ENTRY};
  COLORMAP_TABLE = array [0..255] of COLORMAP_ENTRY;

  { Surfaces }
  PSurf = PInteger;

  { Events }
  PEVENTFN = Pointer;

  EVENT_TYPE = Integer;
  PHEVENT = Pointer;

  { For events, used in eventCreate() }
  EVENT_ATTRIB = (ATTRIB_DRAWORDER,
         ATTRIB_VISIBILITY,
         ATTRIB_POSX,
         ATTRIB_POSY,
         ATTRIB_VIEWX,
         ATTRIB_VIEWDX,
         ATTRIB_VIEWY,
         ATTRIB_VIEWDY,
         ATTRIB_CURRENTIMAGE);

  EVENT_CONSTRAINT = Integer;

  EVENT_STYLE = Integer;
  PEVENT_STYLE = ^EVENT_STYLE;

  EVENT_CONDITION = Integer;

  { For flags in eventSchedule }
  TIMER_FLAGS = (RELATIVE_TIME, ABSOLUTE_TIME);

  EVENTFN_Proc = procedure(hEvent: HEVENT; eMsg: DWORD; eType: DWORD; dwContext: DWORD);

  { RDX Admin }
  { Filter graph object handle }
  HFG = Pointer;
  PHFG = ^HFG;

  { Filter graph video object handle }
  HFGVID = Pointer;
  PHFGVID = ^HFGVID;

  { Filter graph audio object handle }
  HFGAUD = Pointer;
  PHFGAUD = ^HFGAUD;

  PlayMode = (PLAYMODE_ONCE{=0},
              PLAYMODE_REPEAT  );

  FgInfo = (FG_INFO_LENGTH,
            FG_INFO_SAMPLERATE,
            FG_INFO_WIDTH,
            FG_INFO_HEIGHT,
            FG_INFO_COLORDEPTH  );

  State = (STOPPED{=1},
           PAUSED,
           PLAYING,
           UNDEFINED_STATE  );

  SourceType = (SRC_FILE,
                SRC_FILTER,
                SRC_FILTERGRAPH,
                SRC_UNDEFINED  );

  { RDX DinoAV }
  { AV enumerations }
  AVSTATUS = (AV_STATUS_STATE,
              AV_STATUS_CURRENTSAMPLE,
              AV_STATUS_VOLUME,
              AV_STATUS_PAN,
              AV_STATUS_CODECREUSE,
              AV_STATUS_EXCLUSIVEMODE,
              AV_STATUS_SETDECODERECT,
              AV_STATUS_DECODEINIT );

  AVINFO = (AV_INFO_LENGTH,
            AV_INFO_SAMPLERATE,
            AV_INFO_WIDTH,
            AV_INFO_HEIGHT,
            AV_INFO_NUMCHANNELS,
            AV_INFO_BITSPERSAMPLE,
            AV_INFO_COLORDEPTH,
            AV_INFO_4CC,
            AV_INFO_TRANSPARENCY,
            AV_INFO_WAVEFORMAT );

  { AV types }
  HFIL = Pointer;
  PHFIL = ^HFIL;

  HAV = Pointer;
  PHAV = ^HAV;

  HTRACK = Pointer;
  PHTRACK = ^HTRACK;

  HTABLE = Pointer;
  PHTABLE = ^HTABLE;

const
  { The following error code denotes success }
  ERR_OK = (0);

  { The following error code denotes failure and reason when available }
  ERR_FAILED = (- 1);
  ERR_OUT_OF_MEMORY = (- 2);
  ERR_BAD_POINTER = (- 3);
  ERR_OUT_OF_RANGE = (- 4);
  ERR_INVALID_SIZE = (- 5);
  ERR_BAD_TYPE = (- 6);
  ERR_INVALID_ATTRIB = (- 7);
  ERR_INVALID_DRAWORDER = (- 8);
  ERR_INVALID_EFFECT = (- 9);
  ERR_BAD_HANDLE_TYPE = (-10);
  ERR_UNKNOWN_TSTYLE = (-11);
  ERR_FILE_NOT_FOUND = (-12);
  ERR_NOT_VALID_BMP = (-13);
  ERR_FAILED_READING_FILE = (-14);
  ERR_DIFFERENT_BMPS = (-15);
  ERR_OBJECT_ALREADY_A_MEMBER = (-16);
  ERR_OBJECT_NOT_A_MEMBER = (-17);
  ERR_DATA_UNAVAILABLE = (-18);
  ERR_NO_MSG_FN = (-19);
  ERR_UNSUPPORTED = (-20);
  ERR_BADWIDTH = (-21);
  ERR_BADHEIGHT = (-22);
  ERR_UNSUPPORTED_COLORTYPE = (-23);
  ERR_UNSUPPORTED_BITCOUNT = (-24);
  ERR_BADDESTINATION = (-25);
  ERR_BADHWND = (-26);
  ERR_BADEVENTTYPE = (-27);
  ERR_BADFLAGS = (-28);
  ERR_UNSUPPORTED_TSTYLE = (-29);
  ERR_INVALID_RECTL = (-30);
  ERR_INVALID_USAGE = (-31);
  ERR_BAD_FILENAME = (-32);
  ERR_DCIMGR_UNAVAILABLE = (-33);
  ERR_INVALIDCOLOR = (-34);
  ERR_NOPRIORSETTING = (-35);
  ERR_CANNOT_ACCESS_DISPLAY = (-36);
  ERR_BAD_HANDLE = (-37);
  ERR_BAD_TILEWIDTH = (-38);
  ERR_BAD_TILEHEIGHT = (-39);

  { Additional error messages just for timers }
  ERR_BADFREQ = (-40);
  ERR_TIMER_ALREADY_STARTED = (-41);
  ERR_TIMER_FAILED = (-42);
  ERR_TIMER_NOT_RUNNING = (-43);
  ERR_CANNOT_KILL_TIMER = (-44);
  ERR_INVALID_HOBJ = (-45);
  ERR_INVALID_CONSTRAINT = (-46);
  ERR_INVALID_CONDITION = (-47);
  ERR_TIME_ALREADY_PAST = (-48);
  ERR_INVALID_PERIOD = (-49);
  ERR_EVENT_NOT_SCHEDULED = (-50);

  { Joystick messages }
  ERR_TIMEOUT = (-51);
  ERR_NOP = (-52);
  { Currently pentium is required since joystick code uses RDTSC }
  ERR_PENTIUM_REQUIRED = (-53);

  { Effect error messages }
  ERR_EFFECT_NOT_FOUND = (-60);
  ERR_MEDIA_UNSUPPORTED = (-61);
  ERR_INVALID_PARAMS = (-62);
  ERR_BAD_PARAM_SIZE = (-63);
  ERR_NOT_ENOUGH_FORMATS = (-64);

  { Collision error messages }
  ERR_BAD_COLL_DATA = (-65);
  ERR_UNKNOWN_COLL_TYPE = (-66);

  { Direct Draw error messages }
  ERR_CANNOT_ACCESS_DDRAW_SURFACE = (-67);
  ERR_TRANSPARENCY_NOT_SET = (-68);
  ERR_VIDEO_MODE_CONFLICT = (-69);
  ERR_EFFECT_UNSUPPORTED = (-70); { Custom effect error return code}
  ERR_INCOMPATIBLE_COLORTYPES = (-71);
  ERR_INTERNAL_SYS_ERROR = (-100);

  { Status code denotes an invalid parameter was used and was adjusted appropriately }
  ERR_CLIPPED_RANGE = (1);

  { Collision status returns }
  ERR_NO_COLLISION = (2);
  ERR_NO_COLLISION_DATA = (3);

  { AV error messages }
  ERR_NO_BUFFERS = (ERR_OK - 200);
  ERR_AV_FILE_ERROR = (ERR_OK - 201);
  ERR_NOT_PLAYING = (ERR_OK - 202);
  ERR_NOT_PAUSED = (ERR_OK - 203);
  ERR_CODEC_ERROR = (ERR_OK - 204);
  ERR_INVALID_POS = (ERR_OK - 205);
  ERR_AUDIO_ERROR = (ERR_OK - 206);
  ERR_AVNOCODEC = (ERR_OK - 207);
  ERR_AV_INUSE = (ERR_OK - 208);
  ERR_NO_CMDS = (ERR_OK - 209);
  ERR_INVALID_STATUSTYPE = (ERR_OK - 210);
  ERR_INVALID_INFOTYPE = (ERR_OK - 211);
  ERR_PLAY_PAST_END = (ERR_OK - 212);
  ERR_CORRUPTED_TRACK = (ERR_OK - 213);
  ERR_INVALID_TRACK = (ERR_OK - 214);
  ERR_NO_MASTER_TRACK = (ERR_OK - 215);
  ERR_NO_STREAMS = (ERR_OK - 216);
  ERR_INVALID_STREAM = (ERR_OK - 217);
  ERR_CORRUPTED_FIL = (ERR_OK - 218);
  ERR_UNSUPPORTED_AUDIO_FORMAT = (ERR_OK - 219);
  ERR_ALREADY_PLAYING = (ERR_OK - 220);
  ERR_OUT_OF_RESOURCES = (ERR_OK - 221);
  ERR_DS_TURNED_OFF = (ERR_OK - 222);
  ERR_DS_NO_DLL = (ERR_OK - 223);
  ERR_DS_INVALID_DLL = (ERR_OK - 224);
  ERR_DS_NO_DRIVER = (ERR_OK - 225);
  ERR_DS_ALREADY_IN_USE = (ERR_OK - 226);
  ERR_DS_BAD_FORMAT = (ERR_OK - 227);
  ERR_AUDIO_NOT_AVAILABLE = (ERR_OK - 228);
  ERR_TOO_MANY_ACTIVE_TRACKS = (ERR_OK - 229);
  ERR_INVALID_HWND = (ERR_OK - 230);

  { Renamed error codes from Dino 2.0 to Dino 2.1 }
  { These are here for backwards compatibility. }

  ERR_CANNOT_ACCESS_DCI_SURFACE = ERR_CANNOT_ACCESS_DISPLAY;
  ERR_NOT_PCM = ERR_UNSUPPORTED_AUDIO_FORMAT;

  { COLLISION }
  COLLISION_RECT_TYPE = 1;

  { RENDER_CALLBACK }
  RENDER_CALLBACK = $00000001;

   { Sprites }
  SPR_FLAG_HWBLIT = 1; // Uses hardware based image blits from video RAM.
  SPR_FLAG_ALL    = 1;

  { Surfaces }
  fSURF_FLAG_HWBLIT = (1);
  fSURF_FLAG_PAGEFLIP = (2);
  fSURF_FLAG_HWCOLORFILL = (4);
  fSURF_FLAG_WAIT4VBI = (8);
  fSURF_FLAG_CLIPPING = (16);
  fSURF_FLAG_ALL = (31);

  { For event functions }
  { Used by eventCreate() }
  fEVENT_SET_ATTRIB = (1);
  fEVENT_ADJUST_ATTRIB = (2);
  fEVENT_SET_EFFECT_ACTIVE = (3);
  fEVENT_DRAW = (5);
  fEVENT_CALLBACK = (7);
  fEVENT_USER = (1000);

  fNO_CONSTRAINT = (0);
  fADJUSTBOUNDS = (1);
  fRANDOMNESS = (2);

  fNO_STYLE = (0);
  fBOUNCE = (1);
  fCYCLE = (2);

  fNO_CONDITION = (0);
  fEVENT_COMPLETE = (1);
  fATTRIB_ADJUST = (2);
  fATTRIB_ADJUST_OVERFLOW = (4);

  { For devices }
  JOYSTICK0 = 1; { joystick num 0}
  JOYSTICK1 = 2; { joystick num 1}

  { Effect GUIDs }
  { FX_HORIZ_FLIP      78B22763-0F77-11cf-95D6-00AA006D7CE1 }
  { FX_VERT_FLIP       78B22764-0F77-11cf-95D6-00AA006D7CE1 }
  { FX_HORIZ_SHEAR     78B22761-0F77-11cf-95D6-00AA006D7CE1 }
  { FX_VERT_SHEAR      78B22762-0F77-11cf-95D6-00AA006D7CE1 }
  { FX_SMORPH          78B22760-0F77-11cf-95D6-00AA006D7CE1 }
  FX_HORIZ_FLIP: TGUID = (
    D1:$78B22763;D2:$0F77;D3:$11CF;D4:($095,$0D6,$000,$0AA,$000,$06D,$07C,$0E1));
  FX_VERT_FLIP: TGUID = (
    D1:$78B22764;D2:$0F77;D3:$11CF;D4:($095,$0D6,$000,$0AA,$000,$06D,$07C,$0E1));
  FX_HORIZ_SHEAR: TGUID = (
    D1:$78B22761;D2:$0F77;D3:$11CF;D4:($095,$0D6,$000,$0AA,$000,$06D,$07C,$0E1));
  FX_VERT_SHEAR: TGUID = (
    D1:$78B22762;D2:$0F77;D3:$11CF;D4:($095,$0D6,$000,$0AA,$000,$06D,$07C,$0E1));
  FX_SMORPH: TGUID = (
    D1:$78B22760;D2:$0F77;D3:$11CF;D4:($095,$0D6,$000,$0AA,$000,$06D,$07C,$0E1));

  { Effect GUIDs (supported only by surfaces) }
  { FX_RENDER_CALLBACK 04D591C1-1DC2-11cf-95D6-00AA006D7CE1 }
  { FX_MODEX_DISPLAY   04D591C2-1DC2-11cf-95D6-00AA006D7CE1 }
  { FX_FULL_SCREEN     04D591C0-1DC2-11cf-95D6-00AA006D7CE1 }
  { FX_MAP_CLUT8       FE576D81-6C5B-11cf-95D6-00AA006D7CE1 }
  { FX_DDRAW_RENDER_CALLBACK DDF26161-A3F8-11cf-B8C8-00AA00B7E179 }
  FX_RENDER_CALLBACK: TGUID = (
    D1:$4D591C1;D2:$1DC2;D3:$11CF;D4:($095,$0D6,$000,$0AA,$000,$06D,$07C,$0E1));
  FX_MODEX_DISPLAY: TGUID = (
    D1:$4D591C2;D2:$1DC2;D3:$11CF;D4:($095,$0D6,$000,$0AA,$000,$06D,$07C,$0E1));
  FX_FULL_SCREEN: TGUID = (
    D1:$4D591C0;D2:$1DC2;D3:$11CF;D4:($095,$0D6,$000,$0AA,$000,$06D,$07C,$0E1));
  FX_MAP_CLUT8: TGUID = (
    D1:$FE576D81;D2:$6C5B;D3:$11CF;D4:($095,$0D6,$000,$0AA,$000,$06D,$07C,$0E1));
  FX_DDRAW_RENDER_CALLBACK: TGUID = (
    D1:$ddf26161;D2:$a3f8;D3:$11CF;D4:($0b8,$0c8,$000,$0AA,$000,$0b7,$0e1,$079));

  { RDX Admin }
  { Callback error codes }
  PLAY_COMPLETE = $01;
  PLAY_USERABORT = $02;

  { Operation aborted because of error }
  PLAY_ERRORABORT = $03;

  { RDX DinoAV }
  { AV defines }
  { Timebase equates, used in avGetTimebase and avSetTimebase }
  AV_TB_MILLISECONDS = 0;
  AV_TB_SAMPLES = 1;

  { Play flags, used in avPlay }
  AV_PLAY_REPEAT = $00000001;
  AV_PLAY_EXCLUSIVE = $00000002; { turns off double buffering}

  { Preload flags, used in avPreload }
  PL_PERSISTENT = $00000001;
  PL_DECOMPRESS = $00000002;
  PL_BACKGROUND = $00000004;
  PL_ENTIRE_STREAM = $00000008;

  { Return values from avGetStatus }
  AV_STOPPED = 0;
  AV_PLAYING = 1;
  AV_PAUSED = 2;

  { Audio sample rates }
  AV_8KHZ = 8000;
  AV_11KHZ = 11025;
  AV_22KHZ = 22050;
  AV_44KHZ = 44100;

  { Audio bits per sample (in a single channel) }
  AV_8BIT = 8;
  AV_16BIT = 16;

  { Audio number of channels }
  AV_MONO = 1;
  AV_STEREO = 2;

  { Audio panning ranges }
  AV_PAN_MIN = -10000;
  AV_PAN_MAX = 10000;
  AV_PAN_DEFAULT = 0;

  { Audio volume ranges }
  AV_VOLUME_MIN = -10000;
  AV_VOLUME_MAX = 0;
  AV_VOLUME_DEFAULT = 0;

  { AV effect GUIDs }
  FX_SCALE2X: TGUID = (
    D1:$2EB42220;D2:$5267;D3:$11CF;D4:($095,$0D6,$000,$0AA,$000,$06D,$07C,$0E1));

{ For bitmaps }
function hbmpCreate(dwWidth: LongInt;
                    dwHeight: LongInt;
                    ColorType: integer;
                    phBmp: Pointer): DINORVAL stdcall;

function hbmpDelete(hBmp: Pointer): DINORVAL stdcall;

function hbmpLoad(hBmp: Pointer;
                  pt: TPoint;
                  pFilename: PChar;
                  rSrc: TRect): DINORVAL stdcall;

function hbmpSetPointer(hBmp: Pointer;
                        pBits: Pointer;
                        dwStride: LongInt): DINORVAL stdcall;

function hbmpGetBits(pBits: Pointer;
                     DstPt: TPoint;
                     dwStride: LongInt;
                     hBmp: Pointer;
                     rSrc: TRect): DINORVAL stdcall;

function hbmpGetLockedBuffer(hBmp: Pointer;
                             pphBmpBuf: Pointer;
                             phBmpHeader: Pointer): DINORVAL stdcall;

function hbmpReleaseBuffer(hBmp: Pointer): DINORVAL stdcall;

function hbmpGetSize(hBmp: Pointer;
                     pWidth: Pointer;
                     pHeight: Pointer): DINORVAL stdcall;

function hbmpPrepare(hBmp: Pointer;
                     usage: Usage;
                     fFlip: Bool): DINORVAL stdcall;

function hbmpSetTransparencyColor(hBmp: Pointer;
                                  color: integer): DINORVAL stdcall;

function hbmpGetTransparencyColor(hBmp: Pointer;
                                  pColor: Pointer): DINORVAL stdcall;

function hbmpSetTransparencyMask(hBmp: Pointer;
                                 pMask: Pointer): DINORVAL stdcall;

function hbmpGetTransparencyMask(hBmp: Pointer;
                                 pMask: Pointer): DINORVAL stdcall;

function hbmpClearTransparency(hBmp: Pointer): DINORVAL stdcall;

function hbmpSetCompressedImage(hBmp: Pointer; pCodes: Pointer; dwLength: integer): DINORVAL stdcall;

function hbmpGetCompressedImage(hBmp: Pointer; pCodes: Pointer; dwLength: integer): DINORVAL stdcall;

{ For Sequences }
function hseqCreate(count: integer;
                    width: integer;
                    height: integer;
                    color: integer;
                    phSeq: Pointer): DINORVAL stdcall;

function hseqSetData(hSeq: Pointer;
                     index: integer;
                     hBmp: Pointer): DINORVAL stdcall;

function hseqGetData(hSeq: Pointer;
                     index: integer;
                     phBmp: Pointer): DINORVAL stdcall;

function hseqDelete(hSeq: Pointer): DINORVAL stdcall;

{ For Sprites }
function sprCreate(phSpr: Pointer): DINORVAL stdcall;

function sprSetData(hSpr: Pointer;
                    hBmp: Pointer): DINORVAL stdcall;

function sprGetData(hSpr: Pointer;
                    phBmp: Pointer): DINORVAL stdcall;

function sprDelete(hSpr: Pointer): DINORVAL stdcall;

function sprSetFlags(hSpr: Pointer; flags: integer): DINORVAL stdcall;

function sprGetFlags(hSpr: HSPR; pflags: Pointer): DINORVAL stdcall;

function sprClearFlags(hSpr: Pointer; flags: integer): DINORVAL stdcall;


{ For Backgrounds }
function bkgCreate(phBkg: Pointer): DINORVAL stdcall;

function bkgSetData(hBkg: Pointer;
                    hBmp: Pointer): DINORVAL stdcall;

function bkgGetData(hBkg: Pointer;
                    phBmp: Pointer): DINORVAL stdcall;

function bkgDelete(hBkg: Pointer): DINORVAL stdcall;

function bkgSetFlags(hBkg: Pointer; flags: integer): DINORVAL stdcall;

function bkgGetFlags(hBkg: Pointer; pflags: Pointer): DINORVAL stdcall;

function bkgClearFlags(hBkg: Pointer; flags: integer): DINORVAL stdcall;

{ For Tiles }
function tleCreate(phTile: Pointer): DINORVAL stdcall;

function tleSetData(hTile: HTILE;
                    hBmp: HBMP): DINORVAL stdcall;

function tleGetData(hTile: HTILE;
                    phBmp: HBMP): DINORVAL stdcall;

function tleDelete(hTile: HTILE): DINORVAL stdcall;

{ For Grids }
function grdCreateEx(wTilesWide: Word;
                     wTilesHigh: Word;
                     wTileWidth: Word;
                     wTileHeight: Word;
                     iColorType: COLORTYPE;
                     phGrid: Pointer): DINORVAL stdcall;

function grdSetData(hGrid: HGRID;
                    loc: GrdLocation;
                    hTile: HTILE): DINORVAL stdcall;

function grdGetData(hGrid: HGRID;
                    loc: GrdLocation;
                    phTile: HTILE): DINORVAL stdcall;

function grdClearData(hGrid: HGRID;
                      loc: GrdLocation): DINORVAL stdcall;

function grdDelete(hGrid: HGRID): DINORVAL stdcall;

{ GrdCreate() is for backwards compatibility with RDX 2.0 and is now obsolete. }
function grdCreate(wTilesWide: Word;
                   wTilesHigh: Word;
                   wTileWidth: Word;
                   wTileHeight: Word;
                   phGrid: Pointer): DINORVAL stdcall;

{ ************************************************************************************ }
{ Object attribute manipulation functions, surface management functions }
{ ************************************************************************************ }

{ For surfaces }
function srfCreate(dwWidth: integer;
                   dwHeight: integer;
                   ColorType: integer;
                   phSurf: Pointer): DINORVAL stdcall;

function srfDelete(hSurf: Pointer): DINORVAL stdcall;

function srfSetColor(hSurf: Pointer;
                     dwColor: integer): DINORVAL stdcall;

function srfGetColor(hSurf: Pointer;
                     pdwColor: Pointer): DINORVAL stdcall;

function srfClearColor(hSurf: Pointer): DINORVAL stdcall;

function srfSetFlags(hSurf: Pointer;
                     flags: Pointer): DINORVAL stdcall;

function srfGetFlags(hSurf: Pointer;
                     pFlags: Pointer): DINORVAL stdcall;

function srfClearFlags(hSurf: Pointer;
                       flags: Pointer): DINORVAL stdcall;

function srfSetDestWindow(hSurf: Pointer;
                          hWnd: HWND): DINORVAL stdcall;

function srfGetDestWindow(hSurf: Pointer;
                          phWnd: Pointer): DINORVAL stdcall;

function srfSetDestMemory(hSurf: Pointer;
                          pBuffer: Pointer;
                          lStride: integer): DINORVAL stdcall;

function srfGetDestMemory(hSurf: Pointer;
                          pBuffer: Pointer;
                          plStride: Pointer): DINORVAL stdcall;

function srfDraw(hSurf: Pointer): DINORVAL stdcall;


{ Attribute manipulation functions }
function objSetDrawOrder(hObj: Pointer;
                         dwDrawOrder: LongInt): DINORVAL stdcall;

function objAdjDrawOrder(hObj: Pointer;
                         lDrawOrder: LongInt): DINORVAL stdcall;

function objGetDrawOrder(hObj: Pointer;
                         pdwDrawOrder: PLongInt): DINORVAL stdcall;

function objSetVisibility(hObj: Pointer;
                          lDisplay: LongInt): DINORVAL stdcall;

function objAdjVisibility(hObj: Pointer;
                          lDisplay: LongInt): DINORVAL stdcall;

function objGetVisibility(hObj: Pointer;
                          plDisplay: PLongInt): DINORVAL stdcall;

function objSetPosition(hObj: Pointer;
                        pt: TPoint): DINORVAL stdcall;

function objAdjPosition(hObj: Pointer;
                        pt: TPoint): DINORVAL stdcall;

function objGetPosition(hObj: Pointer;
                        pPt: PPOINT): DINORVAL stdcall;

function objSetView(hObj: Pointer;
                    rwhSrc: TRect): DINORVAL stdcall;

function objAdjView(hObj: Pointer;
                    rwhSrc: TRect): DINORVAL stdcall;

function objGetView(hObj: Pointer;
                    prwhSrc: TRect): DINORVAL stdcall;

function objSetCurrentImage(hObj: Pointer;
                            lIndex: LongInt): DINORVAL stdcall;

function objAdjCurrentImage(hObj: Pointer;
                            lIndex: LongInt): DINORVAL stdcall;

function objGetCurrentImage(hObj: Pointer;
                            plIndex: PLongInt): DINORVAL stdcall;

function objSetDestRect(hObj: Pointer;
                        rwhDest: TRect): DINORVAL stdcall;

function objAdjDestRect(hObj: Pointer;
                        rwhDest: TRect): DINORVAL stdcall;

function objGetDestRect(hObj: Pointer;
                        prwhDest: TRect): DINORVAL stdcall;

function objSetDestination(hObj: Pointer;
                           hSurf: Pointer): DINORVAL stdcall;

function objGetDestination(hObj: Pointer;
                           phSurf: PSurf): DINORVAL stdcall;

function objApplyEffect(hObj: Pointer;
                        fxID: TGUID;
                        pParams: Pointer;
                        phFx: PHFX): DINORVAL stdcall;

function objRemoveEffect(hObj: Pointer;
                         hFx: HFX): DINORVAL stdcall;

function objPrepare(hObj: Pointer): DINORVAL stdcall;

{ Collision functions }
function objSetCollisionData(hobj: HOBJ;
                             pCDC: PCollision_Data): DINORVAL stdcall;

function objGetCollisionData(hobj: HOBJ;
                             dwSizeOfBuf: LongInt;
                             pBuf: Pointer;
                             pCDC: PCollision_Data): DINORVAL stdcall;


function objClearCollisionData(hobj: HOBJ): DINORVAL stdcall;


function objTestCollisionData(hobj1: HOBJ;
                              hobj2: HOBJ;
                              pCollList: PCollision_Pair): DINORVAL stdcall;

function objTestCollisionPt(hobj: HOBJ;
                            pt: TPoint;
                            pCollList: PCollision_Pair): DINORVAL stdcall;


{ Effect functions }
function fxSetActive(hFx: HFX;
                     bState: Bool): DINORVAL stdcall;

function fxGetActive(hFx: HFX;
                     pbState: PBool): DINORVAL stdcall;

function fxSetParams(hFx: HFX;
                     pParams: Pointer): DINORVAL stdcall;

function fxGetParams(hFx: HFX;
                     pParams: Pointer): DINORVAL stdcall;

function fxSetLimits(hFx: HFX; 
                     dwInWidth: LongInt;
                     dwInHeight: LongInt;
                     dwOutWidth: LongInt;
                     dwOutHeight: LongInt;
                     pParams: Pointer): DINORVAL stdcall;

function fxGetLimits(hFx: HFX;
                     pdwInWidth: PLongInt;
                     pdwInHeight: PLongInt;
                     pdwOutWidth: PLongInt;
                     pdwOutHeight: PLongInt;
                     pParams: Pointer;
                     size: Integer): DINORVAL stdcall;

{ Group functions }
function grpCreate(phGrp: Pointer): DINORVAL stdcall;

function grpDelete(hGrp: HGRP): DINORVAL stdcall;

function grpAddObject(hGrp: HGRP;
                      hObj: HOBJ): DINORVAL stdcall;

function grpRemoveObject(hGrp: HGRP;
                         hObj: HOBJ): DINORVAL stdcall;

function grpListObjects(hGrp: HGRP;
                        lpBuffer: PHOBJ;
                        wBufferSize: Word): DINORVAL stdcall;

function grpGetNumObjects(hGrp: HGRP;
                          pNum: PLongInt): DINORVAL stdcall;

{ Timer functions }
function timerCreate(TimerFreq: Word;
                     phTimer: Pointer): DINORVAL stdcall;

function timerSetFrequency(hTimer: HTIMER;
                           TimerFreq: Word): DINORVAL stdcall;

function timerGetFrequency(hTimer: HTIMER;
                           pTimerFreq: PWord): DINORVAL stdcall;

function timerStart(hTimer: HTIMER): DINORVAL stdcall;

function timerReset(hTimer: HTIMER): DINORVAL stdcall; 

function timerStop(hTimer: HTIMER): DINORVAL stdcall;

function timerDelete(hTimer: HTIMER): DINORVAL stdcall;

function timerGetCurrentTick(hTimer: HTIMER;
                             pTick: PLongInt): DINORVAL stdcall;

function timerSetCurrentTick(hTimer: HTIMER;
                             Tick: LongInt): DINORVAL stdcall;

{ Event functions }
function eventCreate(hObj: HOBJ;
                     dwEventType: EVENT_TYPE;
                     lParam1: LongInt;
                     lParam2: LongInt;
                     phEvent: Pointer): DINORVAL stdcall;

function eventDelete(hEvent: HEVENT): DINORVAL stdcall;

function eventContinue(hEvent: HEVENT;
                       lTimes: LongInt): DINORVAL stdcall;

function eventSchedule(hTimer: HTIMER;
                       hEvent: HEVENT;
                       dwStartTick: LongInt;
                       flags: TIMER_FLAGS;
                       wPeriod: Word;
                       dwTimes: LongInt): DINORVAL stdcall;

function eventSetAdjustConstraint(hEvent: HEVENT;
                                  iConstraint: EVENT_CONSTRAINT;
                                  iStyle: EVENT_STYLE;
                                  lMin: LongInt;
                                  lMax: LongInt): DINORVAL stdcall;

function eventGetAdjustConstraint(hEvent: HEVENT;
                                  iConstraint: EVENT_CONSTRAINT;
                                  piStyle: PEVENT_STYLE;
                                  plMax: PLongInt;
                                  plMin: PLongInt): DINORVAL stdcall;

function eventClearAdjustConstraint(hEvent: HEVENT;
                                    iConstraint: EVENT_CONSTRAINT): DINORVAL stdcall;

function eventSetConstraintCallback(hEvent: HEVENT;
                                    iCondition: EVENT_CONDITION;
                                    pfnCB: PEVENTFN;
                                    lContext: LongInt): DINORVAL stdcall;

function eventGetConstraintCallback(hEvent: HEVENT;
                                    iCondition: EVENT_CONDITION;
                                    pfnCB: PEVENTFN;
                                    plContext: PLongInt): DINORVAL stdcall;

function devStartJoystick(StickNum: Integer): DINORVAL stdcall;

function devReadJoystick(iStick: Integer;
                         pdwXPos: PLongInt;
                         pdwYPos: PLongInt;
                         bButtons: PBYTE): DINORVAL stdcall;


function devSetPalette(dwNumValues: LongInt; 
                       dwStart: LongInt;
                       pValues: PRGBQuad): DINORVAL stdcall;

function devGetPalette(dwNumValues: LongInt;
                       dwStart: LongInt;
                       pValues: PRGBQuad): DINORVAL stdcall;


function devQueryVideoMode(iIndex: Integer;
                           pWidth: PLongInt;
                           pHeight: PLongInt;
                           pColorType: PColorType;
                           pReserved: Pointer): DINORVAL stdcall;

{ RDX Admin Functions }
function fgVideoCreate(phfgVid: PHFGVID): DINORVAL stdcall;

function fgVideoDelete(hfgVid: HFGVID): DINORVAL stdcall;

{function fgvidAssociateRenderer(hfgVid: HFGVID;
                                pRenderer: PIFILTER): DINORVAL stdcall;}

function fgvidGetVideoPalette(hfgVid: HFGVID;
                              pPalette: PLogPalette): DINORVAL stdcall;

{function fgGetFiltergraphManager(hfg: HFG;
                                 pFg: PIGRAPHBUILDER*): DINORVAL stdcall;}

{function fgAssociateFilterGraph(hFilterGraph: HFG;
                                pGraph: PIGRAPHBUILDER;
                                pRDXSrc: PIFILTER): DINORVAL stdcall;}

function fgCreate(phfilterGraph: PHFG): DINORVAL stdcall;

function fgDelete(hfg: HFG): DINORVAL stdcall;

function fgAssociateFile(hFilterGraph: HFG;
                         pFileName: PChar): DINORVAL stdcall;

{function fgAssociateFilter(hFilterGraph: HFG;
                           Const pFilterGuid: PGUID): DINORVAL stdcall;}

function fgGetNumStreams(hFilterGraph: HFG;
                         pnumVideoStreams: PLongInt;
                         pnumAudioStreams: PLongInt): DINORVAL stdcall;

function fgPlay(hfg: HFG;
                mode: Word; 
                dwStart: LongInt;
                dwStop: LongInt): DINORVAL stdcall; 

function fgPause(hfg: HFG): DINORVAL stdcall;

function fgResume(hfg: HFG): DINORVAL stdcall; 

function fgStop(hfg: HFG): DINORVAL stdcall; 

function fgGetState(hfg: HFG; 
                    pStatusInfo: Pointer): DINORVAL stdcall; 

function fgGetVidInfo(hfg: HFG; 
                      hfgVid: HFGVID; 
                      infoType: FgInfo;
                      pInfo: Pointer): DINORVAL stdcall; 

function fgvidSetTransparencyColor(hfgVid: HFGVID; 
                                   Color: Integer): DINORVAL stdcall; 

function fgvidGetTransparencyColor(hfgVid: HFGVID;
                                   Color: PInteger): DINORVAL stdcall;

function fgvidClearTransparency(hfgVid: HFGVID): DINORVAL stdcall; 

{function fgNotifyEvent(hFilterGraph: HFG;
                       fg: VOID (*FP)(HFG;
                       evCode): LongInt): DINORVAL stdcall;}

function fgSeek(hfilterGraph: HFG; 
                llTime: LongInt): DINORVAL stdcall; 

function fgGetPosition(hfilterGraph: HFG;
                       llTime: PLongInt): DINORVAL stdcall;

function fgSetPlayRate(hFilterGraph: HFG; 
                       rate: Double): DINORVAL stdcall;

function fgGetPlayRate(hFilterGraph: HFG; 
                       rate: PDouble): DINORVAL stdcall;

function fgSetAudioVolume(hFilterGraph: HFG; 
                          lVolume: LongInt): DINORVAL stdcall; 

function fgGetAudioVolume(hFilterGraph: HFG;
                          plVolume: PLongInt): DINORVAL stdcall; 

function fgSetAudioBalance(hFilterGraph: HFG; 
                           lBalance: LongInt): DINORVAL stdcall; 

function fgGetAudioBalance(hFilterGraph: HFG;
                           plBalance: PLongInt): DINORVAL stdcall;

function fgGetAudioObject(hFilterGraph: HFG;
                          iAudioIndex: LongInt;
                          hfgAud: PHFGAUD): DINORVAL stdcall;

function fgGetVideoObject(hFilterGraph: HFG;
                          iVideoIndex: LongInt;
                          hfgVid: PHFGVID): DINORVAL stdcall;

{ DXR DinoAV function prototypes }
{ General functions }
function avSetSysDefaultTimer(hTimer: HTIMER): DINORVAL stdcall;


function avGetSysAudioFormat(pSamplesPerSec: PLongInt;
                             pBitsPerSample: PWord; 
                             pChannels: PWord;
                             phMainWnd: PHWND): DINORVAL stdcall;

function avSetSysAudioFormat(nSamplesPerSec: LongInt;
                             nBitsPerSample: Word; 
                             nChannels: Word; 
                             hMainWnd: HWND): DINORVAL stdcall; 

{ HFIL specific functions }
function hfilCreate(phfil: PHFIL): DINORVAL stdcall;

function hfilDelete(hfil: HFIL): DINORVAL stdcall; 


function hfilLoad(hfil: HFIL; 
                  pszFilename: PChar): DINORVAL stdcall;


function hfilFlush(hfil: HFIL): DINORVAL stdcall;

function hfilPreload(hfil: HFIL; 
                     dwPreloadFlags: LongInt;
                     dwOffset: LongInt;
                     dwFrames: LongInt): DINORVAL stdcall;

{ HAV specific functions }
function avCreate(phAV: PHAV): DINORVAL stdcall;

function avDelete(hAV: HAV): DINORVAL stdcall;


function avGetData(hAV: HAV; 
                   phfil: PHFIL): DINORVAL stdcall; 

function avSetData(hAV: HAV; 
                   hfil: HFIL;
                   phVidTrack: PHTRACK; 
                   phAudTrack: PHTRACK): DINORVAL stdcall; 


function avGetInfo(hAV: HAV; 
                   infoType: AVINFO;
                   pInfo: Pointer): DINORVAL stdcall; 


function avConnectTimer(hAV: HAV; 
                        hTimer: HTIMER): DINORVAL stdcall;

function avDisconnectTimer(hAV: HAV): DINORVAL stdcall;


function avGetTimebase(hAV: HAV; 
                       timeBase: PWord): DINORVAL stdcall; 

function avSetTimebase(hAV: HAV;
                       wTimebase: Word): DINORVAL stdcall; 


function avFlush(hAV: HAV): DINORVAL stdcall;

function avPreload(hAV: HAV;
                   dwPreloadFlags: LongInt;
                   dwOffset: LongInt; 
                   dwFrames: LongInt): DINORVAL stdcall;


function avAddAudioTrack(hAV: HAV; 
                         hfil: HFIL; 
                         streamNum: LongInt;
                         phAudTrack: PHTRACK): DINORVAL stdcall; 

function avRemoveAudioTrack(hAV: HAV;
                            hAudTrack: HTRACK): DINORVAL stdcall;


function avAddVideoTrack(hAV: HAV; 
                         hfil: HFIL; 
                         streamNum: LongInt; 
                         phVidTrack: PHTRACK): DINORVAL stdcall;

function avRemoveVideoTrack(hAV: HAV; 
                            hVidTrack: HTRACK): DINORVAL stdcall; 


function avGetMasterTrack(hAV: HAV; 
                          phTrack: PHTRACK): DINORVAL stdcall;

function avSetMasterTrack(hAV: HAV; 
                          hTrack: HTRACK): DINORVAL stdcall;


function avCreateLoop(hAV: HAV; 
                      dwStart: LongInt;
                      dwEnd: LongInt;
                      dwLoopCount: LongInt; 
                      dwImmediateFlag: LongInt): DINORVAL stdcall; 

function avDeleteLoop(hAV: HAV; 
                      dwStart: LongInt;
                      dwEnd: LongInt): DINORVAL stdcall; 


function avPause(hAV: HAV): DINORVAL stdcall; 

function avPlay(hAV: HAV; 
                dwPlayFlags: LongInt; 
                dwFrom: LongInt; 
                dwTo: LongInt): DINORVAL stdcall; 

function avResume(hAV: HAV): DINORVAL stdcall; 

function avSeek(hAV: HAV; 
                Origin: Integer; 
                lPos: LongInt): DINORVAL stdcall;

function avStop(hAV: HAV): DINORVAL stdcall; 


function avGetStatus(hAV: HAV;
                     statusType: AVSTATUS;
                     statusInfo: Pointer): DINORVAL stdcall;

function avSetStatus(hAV: HAV;
                     statusType: AVSTATUS;
                     lStatusInfo: LongInt): DINORVAL stdcall;

{ HTRACK specific functions }
function audGetInfo(hTrack: HTRACK; 
                    infoType: AVINFO;
                    pInfo: Pointer): DINORVAL stdcall; 


function audGetStatus(hAudTrack: HTRACK; 
                      statusType: AVSTATUS;
                      pStatusInfo: Pointer): DINORVAL stdcall; 

function audSetStatus(hAudTrack: HTRACK; 
                      statusType: AVSTATUS;
                      lStatusInfo: LongInt): DINORVAL stdcall; 


function vidSetTransparencyColor(hTrack: HTRACK;
                                 color: LongInt): DINORVAL stdcall; 

function vidGetTransparencyColor(hTrack: HTRACK;
                                 pColor: PLongInt): DINORVAL stdcall;

function vidClearTransparencyColor(hTrack: HTRACK): DINORVAL stdcall;


function vidGetInfo(hTrack: HTRACK;
                    infoType: AVINFO; 
                    pInfo: Pointer): DINORVAL stdcall; 


function vidGetStatus(hVidTrack: HTRACK; 
                      statusType: AVSTATUS;
                      pStatusInfo: Pointer): DINORVAL stdcall;

function vidSetStatus(hVidTrack: HTRACK; 
                      statusType: AVSTATUS;
                      lStatusInfo: LongInt): DINORVAL stdcall; 


function vidGetPalette(hVidTrack: HTRACK; 
                       pPal: PLogPalette): DINORVAL stdcall; 

function vidSetPalette(hVidTrack: HTRACK; 
                       pPal: PLogPalette): DINORVAL stdcall;


function vidSendCodecMessage(hTrack: HTRACK;
                             dwMsg: LongInt;
                             dwParam1: LongInt; 
                             dwParam2: LongInt): DINORVAL stdcall;


function vidGetFileCollisionData(hVidTrack: HTRACK;
                                 dwFrameNum: LongInt;
                                 dwSizeBuf: LongInt;
                                 pBuf: Pointer;
                                 pCDC: PCollision_Rect_Data): DINORVAL stdcall;

function vidIgnoreFileCollisionData(hVidTrack: HTRACK): DINORVAL stdcall; 

function vidUseFileCollisionData(hVidTrack: HTRACK): DINORVAL stdcall;

{ HTABLE specific functions }
function avCreateBranchTable(hTable: PHTABLE;
                             wNumEntries: Word): DINORVAL stdcall;

function avDeleteBranchTable(hTable: HTABLE): DINORVAL stdcall; 


function avClearBranchTable(hTable: HTABLE): DINORVAL stdcall;


function avClearTableEntry(hTable: HTABLE;
                           wEntryNum: Word): DINORVAL stdcall; 

function avGetTableEntry(hTable: HTABLE; 
                         wEntryNum: Word; 
                         phAV: PHAV;
                         dwOffset: PLongInt; 
                         dwNumFrames: PLongInt): DINORVAL stdcall; 

function avSetTableEntry(hTable: HTABLE; 
                         wEntryNum: Word; 
                         hAV: HAV; 
                         dwOffset: LongInt; 
                         dwNumFrames: LongInt): DINORVAL stdcall;


function avChooseTableEntry(hTable: HTABLE; 
                            wEntryNum: Word;
                            bFlush: Bool;
                            dwPlayFlags: LongInt): DINORVAL stdcall;

implementation

function hbmpGetCompressedImage;        external 'DINO2D.DLL' name '_hbmpGetCompressedImage@12';
function hbmpSetCompressedImage;        external 'DINO2D.DLL' name '_hbmpSetCompressedImage@12';
function hbmpCreate;			external 'DINO2D.DLL' name '_hbmpCreate@16';
function hbmpDelete;			external 'DINO2D.DLL' name '_hbmpDelete@4';
function hbmpLoad;			external 'DINO2D.DLL' name '_hbmpLoad@32';
function hbmpSetPointer;		external 'DINO2D.DLL' name '_hbmpSetPointer@12';
function hbmpGetBits;			external 'DINO2D.DLL' name '_hbmpGetBits@36';
function hbmpGetLockedBuffer;		external 'DINO2D.DLL' name '_hbmpGetLockedBuffer@12';
function hbmpReleaseBuffer;		external 'DINO2D.DLL' name '_hbmpReleaseBuffer@4';
function hbmpGetSize;			external 'DINO2D.DLL' name '_hbmpGetSize@12';
function hbmpPrepare;			external 'DINO2D.DLL' name '_hbmpPrepare@12';
function hbmpSetTransparencyColor;	external 'DINO2D.DLL' name '_hbmpSetTransparencyColor@8';
function hbmpGetTransparencyColor;	external 'DINO2D.DLL' name '_hbmpGetTransparencyColor@8';
function hbmpSetTransparencyMask;	external 'DINO2D.DLL' name '_hbmpSetTransparencyMask@8';
function hbmpGetTransparencyMask;	external 'DINO2D.DLL' name '_hbmpGetTransparencyMask@8';
function hbmpClearTransparency;		external 'DINO2D.DLL' name '_hbmpClearTransparency@4';
function hseqCreate;			external 'DINO2D.DLL' name '_hseqCreate@20';
function hseqSetData;			external 'DINO2D.DLL' name '_hseqSetData@12';
function hseqGetData;			external 'DINO2D.DLL' name '_hseqGetData@12';
function hseqDelete;			external 'DINO2D.DLL' name '_hseqDelete@4';
function sprCreate;			external 'DINO2D.DLL' name '_sprCreate@4';
function sprSetData;			external 'DINO2D.DLL' name '_sprSetData@8';
function sprGetData;			external 'DINO2D.DLL' name '_sprGetData@8';
function sprDelete;			external 'DINO2D.DLL' name '_sprDelete@4';
function sprClearFlags;		        external 'DINO2D.DLL' name '_sprClearFlags@8';
function sprGetFlags;		        external 'DINO2D.DLL' name '_sprGetFlags@8';
function sprSetFlags;		        external 'DINO2D.DLL' name '_sprSetFlags@8';

function bkgCreate;			external 'DINO2D.DLL' name '_bkgCreate@4';
function bkgSetData;			external 'DINO2D.DLL' name '_bkgSetData@8';
function bkgGetData;			external 'DINO2D.DLL' name '_bkgGetData@8';
function bkgDelete;			external 'DINO2D.DLL' name '_bkgDelete@4';
function bkgGetFlags;			external 'DINO2D.DLL' name '_bkgGetFlags@8';
function bkgSetFlags;			external 'DINO2D.DLL' name '_bkgSetFlags@8';
function bkgClearFlags;			external 'DINO2D.DLL' name '_bkgClearFlags@8';

function tleCreate;			external 'DINO2D.DLL' name '_tleCreate@4';
function tleSetData;			external 'DINO2D.DLL' name '_tleSetData@8';
function tleGetData;			external 'DINO2D.DLL' name '_tleGetData@8';
function tleDelete;			external 'DINO2D.DLL' name '_tleDelete@4';

function grdCreateEx;			external 'DINO2D.DLL' name '_grdCreateEx@24';
function grdSetData;			external 'DINO2D.DLL' name '_grdSetData@12';
function grdGetData;			external 'DINO2D.DLL' name '_grdGetData@12';
function grdClearData;			external 'DINO2D.DLL' name '_grdClearData@8';
function grdDelete;			external 'DINO2D.DLL' name '_grdDelete@4';
function grdCreate;			external 'DINO2D.DLL' name '_grdCreate@20';

function srfCreate;			external 'DMIX.DLL' name '_srfCreate@16';
function srfDelete;			external 'DMIX.DLL' name '_srfDelete@4';
function srfSetColor;			external 'DMIX.DLL' name '_srfSetColor@8';
function srfGetColor;			external 'DMIX.DLL' name '_srfGetColor@8';
function srfClearColor;			external 'DMIX.DLL' name '_srfClearColor@4';
function srfSetFlags;			external 'DMIX.DLL' name '_srfSetFlags@8';
function srfGetFlags;			external 'DMIX.DLL' name '_srfGetFlags@8';
function srfClearFlags;			external 'DMIX.DLL' name '_srfClearFlags@8';
function srfSetDestWindow;		external 'DMIX.DLL' name '_srfSetDestWindow@8';
function srfGetDestWindow;		external 'DMIX.DLL' name '_srfGetDestWindow@8';
function srfSetDestMemory;		external 'DMIX.DLL' name '_srfSetDestMemory@12';
function srfGetDestMemory;		external 'DMIX.DLL' name '_srfGetDestMemory@12';
function srfDraw;			external 'DMIX.DLL' name '_srfDraw@4';

function objSetDrawOrder;		external 'DMIX.DLL' name '_objSetDrawOrder@8';
function objAdjDrawOrder;		external 'DMIX.DLL' name '_objAdjDrawOrder@8';
function objGetDrawOrder;		external 'DMIX.DLL' name '_objGetDrawOrder@8';
function objSetVisibility;		external 'DMIX.DLL' name '_objSetVisibility@8';
function objAdjVisibility;		external 'DMIX.DLL' name '_objAdjVisibility@8';
function objGetVisibility;		external 'DMIX.DLL' name '_objGetVisibility@8';
function objSetPosition;		external 'DMIX.DLL' name '_objSetPosition@12';
function objAdjPosition;		external 'DMIX.DLL' name '_objAdjPosition@12';
function objGetPosition;		external 'DMIX.DLL' name '_objGetPosition@8';
function objSetView;			external 'DMIX.DLL' name '_objSetView@20';
function objAdjView;			external 'DMIX.DLL' name '_objAdjView@20';
function objGetView;			external 'DMIX.DLL' name '_objGetView@8';
function objSetCurrentImage;		external 'DMIX.DLL' name '_objSetCurrentImage@8';
function objAdjCurrentImage;		external 'DMIX.DLL' name '_objAdjCurrentImage@8';
function objGetCurrentImage;		external 'DMIX.DLL' name '_objGetCurrentImage@8';
function objSetDestRect;		external 'DMIX.DLL' name '_objSetDestRect@20';
function objAdjDestRect;		external 'DMIX.DLL' name '_objAdjDestRect@20';
function objGetDestRect;		external 'DMIX.DLL' name '_objGetDestRect@8';
function objSetDestination;		external 'DMIX.DLL' name '_objSetDestination@8';
function objGetDestination;		external 'DMIX.DLL' name '_objGetDestination@8';
function objApplyEffect;		external 'DMIX.DLL' name '_objApplyEffect@28';
function objRemoveEffect;		external 'DMIX.DLL' name '_objRemoveEffect@8';
function objPrepare;			external 'DMIX.DLL' name '_objPrepare@4';
function objSetCollisionData;		external 'DMIX.DLL' name '_objSetCollisionData@16';
function objGetCollisionData;		external 'DMIX.DLL' name '_objGetCollisionData@16';
function objClearCollisionData;		external 'DMIX.DLL' name '_objClearCollisionData@4';
function objTestCollisionData;		external 'DMIX.DLL' name '_objTestCollisionData@12';
function objTestCollisionPt;		external 'DMIX.DLL' name '_objTestCollisionPt@16';

function fxSetActive;			external 'DMIX.DLL' name '_fxSetActive@8';
function fxGetActive;			external 'DMIX.DLL' name '_fxGetActive@8';
function fxSetParams;			external 'DMIX.DLL' name '_fxSetParams@8';
function fxGetParams;			external 'DMIX.DLL' name '_fxGetParams@8';
function fxSetLimits;			external 'DMIX.DLL' name '_fxSetLimits@24';
function fxGetLimits;			external 'DMIX.DLL' name '_fxGetLimits@28';

function grpCreate;			external 'DMIX.DLL' name '_grpCreate@4';
function grpDelete;			external 'DMIX.DLL' name '_grpDelete@4';
function grpAddObject;			external 'DMIX.DLL' name '_grpAddObject@8';
function grpRemoveObject;		external 'DMIX.DLL' name '_grpRemoveObject@8';
function grpListObjects;		external 'DMIX.DLL' name '_grpListObjects@12';
function grpGetNumObjects;		external 'DMIX.DLL' name '_grpGetNumObjects@8';

function timerCreate;			external 'DMIX.DLL' name '_timerCreate@8';
function timerSetFrequency;		external 'DMIX.DLL' name '_timerSetFrequency@8';
function timerGetFrequency;		external 'DMIX.DLL' name '_timerGetFrequency@8';
function timerStart;			external 'DMIX.DLL' name '_timerStart@4';
function timerReset;			external 'DMIX.DLL' name '_timerReset@4';
function timerStop;			external 'DMIX.DLL' name '_timerStop@4';
function timerDelete;			external 'DMIX.DLL' name '_timerDelete@4';
function timerGetCurrentTick;		external 'DMIX.DLL' name '_timerGetCurrentTick@8';
function timerSetCurrentTick;		external 'DMIX.DLL' name '_timerSetCurrentTick@8';

function eventCreate;			external 'DMIX.DLL' name '_eventCreate@20';
function eventDelete;			external 'DMIX.DLL' name '_eventDelete@4';
function eventContinue;			external 'DMIX.DLL' name '_eventContinue@8';
function eventSchedule;			external 'DMIX.DLL' name '_eventSchedule@24';
function eventSetAdjustConstraint;	external 'DMIX.DLL' name '_eventSetAdjustConstraint@20';
function eventGetAdjustConstraint;	external 'DMIX.DLL' name '_eventGetAdjustConstraint@20';
function eventClearAdjustConstraint;	external 'DMIX.DLL' name '_eventClearAdjustConstraint@8';
function eventSetConstraintCallback;	external 'DMIX.DLL' name '_eventSetConstraintCallback@16';
function eventGetConstraintCallback;	external 'DMIX.DLL' name '_eventGetConstraintCallback@16';

function devStartJoystick;		external 'DMIX.DLL' name '_devStartJoystick@4';
function devReadJoystick;		external 'DMIX.DLL' name '_devReadJoystick@16';
function devSetPalette;			external 'DMIX.DLL' name '_devSetPalette@12';
function devGetPalette;			external 'DMIX.DLL' name '_devGetPalette@12';
function devQueryVideoMode;		external 'DMIX.DLL' name '_devQueryVideoMode@20';

{   05    00001a60  _fgCreateEx@8 }
{   07    000019e0  _fgDisableAudio@4 }
{ 0028    00001990  _fgUseSafetyPalette@12 }
{ 0031    000019f0  _fgVideoSetData@12 }
{ 0000    000047f0  audMsgFn }
{ 0018    00004810  fgMsgFn }
{ 0037    00004830  vidMsgFn}

{ RDX Admin Functions }
function fgVideoCreate;			external 'RDXAM.DLL' name '_fgVideoCreate@4';
function fgVideoDelete;			external 'RDXAM.DLL' name '_fgVideoDelete@4';
{function fgvidAssociateRenderer;	external 'RDXAM.DLL' name '_fgvidAssociateRenderer@8';}
function fgvidGetVideoPalette;		external 'RDXAM.DLL' name '_fgvidGetVideoPalette@8';
{function fgGetFiltergraphManager;	external 'RDXAM.DLL' name '_fgGetFiltergraphManager@8';}
function fgCreate;			external 'RDXAM.DLL' name '_fgCreate@4';
function fgDelete;			external 'RDXAM.DLL' name '_fgDelete@4';
function fgAssociateFile;		external 'RDXAM.DLL' name '_fgAssociateFile@8';
{function fgAssociateFilter;		external 'RDXAM.DLL' name '_fgAssociateFilter@8';}
{function fgAssociateFilterGraph;	external 'RDXAM.DLL' name '_fgAssociateFilterGraph@12';}
function fgGetNumStreams;		external 'RDXAM.DLL' name '_fgGetNumStreams@12';
function fgPlay;			external 'RDXAM.DLL' name '_fgPlay@16';
function fgPause;			external 'RDXAM.DLL' name '_fgPause@4';
function fgResume;			external 'RDXAM.DLL' name '_fgResume@4';
function fgStop;			external 'RDXAM.DLL' name '_fgStop@4';
function fgGetState;			external 'RDXAM.DLL' name '_fgGetState@8';
function fgGetVidInfo;			external 'RDXAM.DLL' name '_fgGetVidInfo@16';
function fgvidSetTransparencyColor;	external 'RDXAM.DLL' name '_fgvidSetTransparencyColor@8';
function fgvidGetTransparencyColor;	external 'RDXAM.DLL' name '_fgvidGetTransparencyColor@8';
function fgvidClearTransparency;	external 'RDXAM.DLL' name '_fgvidClearTransparency@4';
{function fgNotifyEvent;		external 'RDXAM.DLL' name '_fgNotifyEvent@8';}
function fgSeek;			external 'RDXAM.DLL' name '_fgSeek@8';
function fgGetPosition;			external 'RDXAM.DLL' name '_fgGetPosition@8';
function fgSetPlayRate;			external 'RDXAM.DLL' name '_fgSetPlayRate@12';
function fgGetPlayRate;			external 'RDXAM.DLL' name '_fgGetPlayRate@12';
function fgSetAudioVolume;		external 'RDXAM.DLL' name '_fgSetAudioVolume@8';
function fgGetAudioVolume;		external 'RDXAM.DLL' name '_fgGetAudioVolume@8';
function fgSetAudioBalance;		external 'RDXAM.DLL' name '_fgSetAudioBalance@8';
function fgGetAudioBalance;		external 'RDXAM.DLL' name '_fgGetAudioBalance@8';
{function fgvidGetVideoPalette;		external 'RDXAM.DLL' index 32;}
function fgGetAudioObject;		external 'RDXAM.DLL' name '_fgGetAudioObject@12'
function fgGetVideoObject;		external 'RDXAM.DLL' name '_fgGetVideoObject@12'

{ RDX DinoAV Functions }
function avSetSysDefaultTimer;		external 'DINOAV.DLL' name '_avSetSysDefaultTimer@4';
function avGetSysAudioFormat;		external 'DINOAV.DLL' name '_avGetSysAudioFormat@16';
function avSetSysAudioFormat;		external 'DINOAV.DLL' name '_avSetSysAudioFormat@16';

function hfilCreate;			external 'DINOAV.DLL' name '_hfilCreate@4';
function hfilDelete;			external 'DINOAV.DLL' name '_hfilDelete@4';
function hfilLoad;			external 'DINOAV.DLL' name '_hfilLoad@8';
function hfilFlush;			external 'DINOAV.DLL' name '_hfilFlush@4';
function hfilPreload;			external 'DINOAV.DLL' name '_hfilPreload@16';

{ _avDisconnectSysAudio@0 }
{ _avReconnectSysAudio@0 }
{ _avDestroySys@4 }
function avCreate;			external 'DINOAV.DLL' name '_avCreate@4';
function avDelete;			external 'DINOAV.DLL' name '_avDelete@4';
function avGetData;			external 'DINOAV.DLL' name '_avGetData@8';
function avSetData;			external 'DINOAV.DLL' name '_avSetData@16';
function avGetInfo;			external 'DINOAV.DLL' name '_avGetInfo@12';
function avConnectTimer;		external 'DINOAV.DLL' name '_avConnectTimer@8';
function avDisconnectTimer;		external 'DINOAV.DLL' name '_avDisconnectTimer@4';
function avGetTimebase;			external 'DINOAV.DLL' name '_avGetTimebase@8'
function avSetTimebase;			external 'DINOAV.DLL' name '_avSetTimebase@8';
function avFlush;			external 'DINOAV.DLL' name '_avFlush@4';
function avPreload;			external 'DINOAV.DLL' name '_avPreload@16';
function avAddAudioTrack;		external 'DINOAV.DLL' name '_avAddAudioTrack@16';
function avRemoveAudioTrack;		external 'DINOAV.DLL' name '_avRemoveAudioTrack@8'
function avAddVideoTrack;		external 'DINOAV.DLL' name '_avAddVideoTrack@16';
function avRemoveVideoTrack;		external 'DINOAV.DLL' name '_avRemoveVideoTrack@8'
function avGetMasterTrack;		external 'DINOAV.DLL' name '_avGetMasterTrack@8';
function avSetMasterTrack;		external 'DINOAV.DLL' name '_avSetMasterTrack@8';
function avCreateLoop;			external 'DINOAV.DLL' name '_avCreateLoop@20';
function avDeleteLoop;			external 'DINOAV.DLL' name '_avDeleteLoop@12';
function avPause;			external 'DINOAV.DLL' name '_avPause@4'
function avPlay;			external 'DINOAV.DLL' name '_avPlay@16'
function avResume;			external 'DINOAV.DLL' name '_avResume@4'
function avSeek;			external 'DINOAV.DLL' name '_avSeek@12';
function avStop;			external 'DINOAV.DLL' name '_avStop@4';
function avGetStatus;			external 'DINOAV.DLL' name '_avGetStatus@12';
function avSetStatus;			external 'DINOAV.DLL' name '_avSetStatus@12';
function avCreateBranchTable;		external 'DINOAV.DLL' name '_avCreateBranchTable@8';
function avDeleteBranchTable;		external 'DINOAV.DLL' name '_avDeleteBranchTable@4';
function avClearBranchTable;		external 'DINOAV.DLL' name '_avClearBranchTable@4';
function avClearTableEntry;		external 'DINOAV.DLL' name '_avClearTableEntry@8';
function avGetTableEntry;		external 'DINOAV.DLL' name '_avGetTableEntry@20';
function avSetTableEntry;		external 'DINOAV.DLL' name '_avSetTableEntry@20';
function avChooseTableEntry;		external 'DINOAV.DLL' name '_avChooseTableEntry@16';

function audGetInfo;			external 'DINOAV.DLL' name '_audGetInfo@12';
function audGetStatus;			external 'DINOAV.DLL' name '_audGetStatus@12';
function audSetStatus;			external 'DINOAV.DLL' name '_audSetStatus@12';

function vidSetTransparencyColor;	external 'DINOAV.DLL' name '_vidSetTransparencyColor@8';
function vidGetTransparencyColor;	external 'DINOAV.DLL' name '_vidGetTransparencyColor@8';
function vidClearTransparencyColor;	external 'DINOAV.DLL' name '_vidClearTransparencyColor@4';
function vidGetInfo;			external 'DINOAV.DLL' name '_vidGetInfo@12';
function vidGetStatus;			external 'DINOAV.DLL' name '_vidGetStatus@12';
function vidSetStatus;			external 'DINOAV.DLL' name '_vidSetStatus@12';
function vidGetPalette;			external 'DINOAV.DLL' name '_vidGetPalette@8';
function vidSetPalette;			external 'DINOAV.DLL' name '_vidSetPalette@8';
function vidSendCodecMessage;		external 'DINOAV.DLL' name '_vidSendCodecMessage@16';
{function vidDraw;			external 'DINOAV.DLL index 49;}
function vidGetFileCollisionData;	external 'DINOAV.DLL' name '_vidGetFileCollisionData@20';
function vidIgnoreFileCollisionData;	external 'DINOAV.DLL' name '_vidIgnoreFileCollisionData@4';
function vidUseFileCollisionData;	external 'DINOAV.DLL' name '_vidUseFileCollisionData@4';

end.

