unit uRdx_Objects;

{
   TRDX Objects - Delphi Object Pascal wrapper for RDX.

   Copyright (c) 1998  A-Couple-A-Nerds Computer Consulting & Jason Kaczor

   	               The demo application, and TRDX Objects system concept included in the "uRDX_Objects.pas"
	               file remain the copyright and intellectual property of Jason Kaczor of A-Couple-A-Nerds
	               Computer Consulting, all rights not specifically granted here are reserved until further
                       notice.

	               Jason Kaczor grants you the right to use, modify, and distribute this source
	               code, your modifications, as long as all files, and copyright notices in this
	               distribution are included, and a full copy is sent back to myself.

	               Jason Kaczor grants you the right to use the TRDX Objects system in your compiled,
	               commercial, freeware, or shareware applications.  When distributing TRDX Objects in
	               compiled form the files, and source code in this distribution need not be included.
	               The only caveat however, is if your compiled application is designed, and targetted
	               at developer's, software engineers, multimedia developers, or computer programmer's
	               you must include all files and copyright notices in this distribution.

                       These copyright notices may change at a future date, to be brought in line with
	               other projects, such as Project Jedi, or GNU.

   Created by:                   Jason Kaczor
                                 A Couple A Nerds Computer Consulting

                                 ACoupleANerds@compuserve.com
		                 kaczor@shaw.wave.ca
		                 Evenings: (403) 283-5351
		                 Daytime:  (403) 716-4466

   Last Change:                  04/23/1998

   Version:                      v.0.9

   Notes:                        v.0.9     Still working on getting full object descriptions.
                                           Expected to get the Threaded RDX Manager working this
                                           weekend (April 26, 1998)


   }

interface

uses
   Windows, SysUtils, Classes, Rdx;

type
  TRDX_Colors = (cl8bit, cl16bit, cl24bit, cl32bit);

  ERDXError = class(Exception);

  TRDXObject = class(TObject)
  private
     fVisible: boolean;
     fHandle: Pointer;
     fDrawOrder: integer;
     fPosition: TPoint;
     fDestination: Pointer;
     fDestRect: TRect;
     fCurrentImage: integer;
     fView: TRect;
     fName: string;
     procedure SetVisible(aVisibility: boolean);
     procedure SetDrawOrder(aDrawOrder: integer);
     procedure SetPosition(aPosition: TPoint);
     procedure SetDestination(aDestination: Pointer);
     procedure SetDestRect(aDestRect: TRect);
     procedure SetCurrentImage(aImage: integer);
     procedure SetView(aView: TRect);
  protected
     property Name: string read fName write fName;
     property Visible: boolean read fVisible write SetVisible;
     property DrawOrder: integer read fDrawOrder write SetDrawOrder;
     property Position: TPoint read fPosition write SetPosition;
     property Destination: Pointer read fDestination write SetDestination;
     property DestinationRect: TRect read fDestRect write SetDestRect;
     property CurrentImage: integer read fCurrentImage write SetCurrentImage;
     property View: TRect read fView write SetView;
     property Handle: Pointer read fHandle write fHandle;
     constructor Create;
  public
     procedure Prepare;
  end;

  TRDXImage = class(TObject)
  private
     fColorType: integer;
     fHeight: integer;
     fWidth: integer;
     fSourcePosition: TPoint;
     fSourceRect: TRect;
     fFileName: string;
     fColor: integer;
     fHandle: Pointer;
     fName: string;
     function GetColors: TRDX_Colors;
  public
     property SourcePosition: TPoint read fSourcePosition write fSourcePosition;
     property SourceRect: TRect read fSourceRect write fSourceRect;
     property FileName: string read fFileName write fFileName;
     property TransparencyColor: integer read fColor write fColor;
     property Width: integer read fWidth;
     property Height: integer read fHeight;
     property Handle: Pointer read fHandle write fHandle;
     property Name: string read fName write fName;
     property Colors: TRDX_Colors read GetColors;
     constructor Create(aName: string; aWidth: integer; aHeight: integer; aColors: TRDX_Colors);
     destructor Destroy; override;
     procedure LoadBitmap;
     procedure LoadCompBitmapFromStream(aStream: TMemoryStream; aSize: integer);
  end;

  TRDXSequence = class(TObject)
  private
     fHandle: Pointer;
     fName: string;
     fItems: TStringList;
  public
     property Handle: Pointer read fHandle write fHandle;
     property Name: string read fName write fName;
     constructor Create(aName: string);
     destructor Destroy; override;
     procedure Add(aItem: string; aImage: TRDXImage);
     procedure Delete(aItem: string);
     function Item(aItem: string): TRDXImage;
  end;

  TRDXBackground = class(TRDXObject)
  private
     fHWBlit: boolean;
     fImageHandle: pointer;
     procedure SetHWBlit(aSetting: boolean);
     procedure SetImageHandle(aImage: Pointer);
  public
     property HWBlit: boolean read fHWBlit write SetHWBlit;
     property ImageHandle: Pointer read fImageHandle write SetImageHandle;
     constructor Create(aName: string);
     destructor Destroy; override;
  published
     property Visible: boolean read fVisible write SetVisible;
     property DrawOrder: integer read fDrawOrder write SetDrawOrder;
     property Position: TPoint read fPosition write SetPosition;
     property Destination: Pointer read fDestination write SetDestination;
     property DestinationRect: TRect read fDestRect write SetDestRect;
     property View: TRect read fView write SetView;
     property Handle: Pointer read fHandle write fHandle;
  end;

  TRDXSurface = class(TRDXObject)
  private
     fColorType: integer;
     fWindowHandle: Hwnd;
     fHeight: integer;
     fWidth: integer;
     procedure SetWindowHandle(aHandle: Hwnd);
     procedure SetColorDepth(aColor: TRDX_Colors);
     function GetColorDepth: TRDX_Colors;
     procedure SetHeight(aHeight: integer);
     procedure SetWidth(aWidth: integer);
  public
     property WindowHandle: Hwnd read fWindowHandle write SetWindowHandle;
     property ColorDepth: TRDX_Colors read GetColorDepth write SetColorDepth;
     property Height: integer read fHeight write SetHeight;
     property Width: integer read fWidth write SetWidth;
     constructor Create(aName: string; aWidth: integer; aHeight: integer; aColors: TRDX_Colors);
     destructor Destroy; override;
     procedure Draw;
  published
     property Visible: boolean read fVisible write SetVisible;
     property DrawOrder: integer read fDrawOrder write SetDrawOrder;
     property Position: TPoint read fPosition write SetPosition;
     property Destination: Pointer read fDestination write SetDestination;
     property DestinationRect: TRect read fDestRect write SetDestRect;
     property View: TRect read fView write SetView;
     property Handle: Pointer read fHandle write fHandle;
  end;

  TRDXSprite = class(TRDXObject)
  private
     fHWBlit: boolean;
     fImageHandle: pointer;
     procedure SetHWBlit(aSetting: boolean);
     procedure SetImageHandle(aImage: Pointer);
  public
     property HWBlit: boolean read fHWBlit write SetHWBlit;
     property ImageHandle: Pointer read fImageHandle write SetImageHandle;
     constructor Create(aName: string);
     destructor Destroy; override;
  published
     property Visible: boolean read fVisible write SetVisible;
     property DrawOrder: integer read fDrawOrder write SetDrawOrder;
     property Position: TPoint read fPosition write SetPosition;
     property Destination: Pointer read fDestination write SetDestination;
     property DestinationRect: TRect read fDestRect write SetDestRect;
     property View: TRect read fView write SetView;
     property Handle: Pointer read fHandle write fHandle;
  end;

  TRDXTile = class(TObject)
  private
  public
  end;

  TRDXGrid = class(TObject)
  private
  public
  end;

  TRDXEffect = class(TObject)
  private
  public
  end;

  TRDXTimer = class(TObject)
  private
  public
  end;

  TRDXEvent = class(TObject)
  private
  public
  end;

  TRDXAudio = class(TObject)
  private
  public
  end;

  TRDXVidio = class(TObject)
  private
  public
  end;

  TRDXManager = class(TThread)
  private
    { Private declarations }
    fJason: longint;
  protected
    { Protected declarations }
    procedure Execute; override;
  public
    { Public declarations }
    property JasonCount: longint read fJason write fJason;
    constructor Create;
    destructor Destroy; override;
  end;

implementation

var
   RDXReturn: longint;

constructor TRDXManager.Create;
begin
     inherited Create(false);

     FreeOnTerminate := true;
end;

destructor TRDXManager.Destroy;
begin
     inherited Destroy;
end;

procedure TRDXManager.Execute;
begin

     while not terminated do
      begin
        Inc(fJason);
        Sleep(20);
      end;

end;

constructor TRDXObject.Create;
begin
     inherited Create;
end;

procedure TRDXObject.Prepare;
begin
     RDXReturn := RDX.objPrepare(fHandle);
     if RDXReturn <> ERR_OK then
        ERDXError.Create('Unable to Prepare RDX object');
end;

procedure TRDXObject.SetDrawOrder(aDrawOrder: integer);
begin
     fDrawOrder := aDrawOrder;

     RDXReturn := RDX.objSetDrawOrder(fHandle, fDrawOrder);
     if RDXReturn <> ERR_OK then
        ERDXError.Create('Unable to set RDX DrawOrder');
end;

procedure TRDXObject.SetDestination(aDestination: Pointer);
begin
     fDestination := aDestination;

     RDXReturn := RDX.objSetDestination(fHandle, fDestination);
     if RDXReturn <> ERR_OK then
        ERDXError.Create('Unable to set RDX Destination');
end;

procedure TRDXObject.SetView(aView: TRect);
begin
     fView := aView;

     RDXReturn := RDX.objSetView(fHandle, fView);
     if RDXReturn <> ERR_OK then
        ERDXError.Create('Unable to set RDX View');
end;

procedure TRDXObject.SetDestRect(aDestRect: TRect);
begin
     fDestRect := aDestRect;

     RDXReturn := RDX.objSetDestRect(fHandle, fDestRect);
     if RDXReturn <> ERR_OK then
        ERDXError.Create('Unable to set RDX DestRect');
end;

procedure TRDXObject.SetCurrentImage(aImage: integer);
begin
     fCurrentImage := aImage;

     RDXReturn := RDX.objSetCurrentImage(fHandle,fCurrentImage);
     if RDXReturn <> ERR_OK then
        ERDXError.Create('Unable to set RDX CurrentImage');
end;

procedure TRDXObject.SetPosition(aPosition: TPoint);
begin
     fPosition := aPosition;

     RDXReturn := RDX.objSetPosition(fHandle,fPosition);
     if RDXReturn <> ERR_OK then
        ERDXError.Create('Unable to set RDX Position');
end;

procedure TRDXObject.SetVisible(aVisibility: boolean);
begin
     fVisible := aVisibility;

     case fVisible of
        true: RDXReturn := RDX.objSetVisibility(fHandle, 1);
        false: RDXReturn := RDX.objSetVisibility(fHandle, 0);
     end;

     if RDXReturn <> ERR_OK then
        ERDXError.Create('Unable to set RDX Visibility');
end;

constructor TRDXImage.Create(aName: string; aWidth: integer; aHeight: integer; aColors: TRDX_Colors);
begin
     inherited Create;

     fHeight := aHeight;
     fWidth  := aWidth;

     case aColors of
        cl8bit: fColorType := 0;
        cl16bit: fColorType := 2;
        cl24bit: fColorType := 3;
        cl32bit: fColorType := 4;
     else
        fColorType := 0;
     end;

     RDXReturn := RDX.hbmpCreate(fWidth, fHeight, fColorType, @Handle);
     if RDXReturn <> ERR_OK then
        ERDXError.Create('Unable to create RDX Bitmap');
end;

function TRDXImage.GetColors: TRDX_Colors;
begin
     case fColorType of
        0: Result := cl8bit;
        2: Result := cl16bit;
        3: Result := cl24bit;
        4: Result := cl32bit;
     else
        Result := cl8bit;
     end;
end;

destructor TRDXImage.Destroy;
begin
     RDX.hbmpDelete(Handle);
     Handle := nil;

     inherited Destroy;
end;

procedure TRDXImage.LoadBitmap;
begin
     if trim(fFileName) <> '' then
      begin
         RDXReturn := RDX.hbmpLoad(Handle, fSourcePosition, PChar(fFileName), fSourceRect);
         if RDXReturn <> ERR_OK then
            ERDXError.Create('Unable to load RDX Bitmap');
      end;
end;

procedure TRDXImage.LoadCompBitmapFromStream(aStream: TMemoryStream; aSize: integer);
begin
     RDXReturn := RDX.hbmpSetCompressedImage(Handle, aStream.Memory, aSize);
     if RDXReturn <> ERR_OK then
        ERDXError.Create('Unable to load RDX Bitmap from compressed stream');
end;

constructor TRDXSequence.Create(aName: string);
begin
     inherited Create;

     fHandle := nil;

     fItems := TStringList.Create;
end;

destructor TRDXSequence.Destroy;
begin
     fItems.Clear;
     fItems.Free;

     if fHandle <> nil then
        RDX.hseqDelete(fHandle);

     fHandle := nil;

     inherited Destroy;
end;

procedure TRDXSequence.Add(aItem: string; aImage: TRDXImage);
var
   ItemCnt: integer;
begin
     fItems.Add(aItem);
     fItems.Objects[fItems.IndexOf(aItem)] := aImage;

     if fHandle <> nil then
        RDX.hseqDelete(fHandle);

     RDXReturn := RDX.hseqCreate(fItems.Count, aImage.Width, aImage.Height, Integer(aImage.Colors), @Handle);
     if RDXReturn <> ERR_OK then
        ERDXError.Create('Unable to add Bitmap to RDX Bitmap Sequence')
     else
      begin
         for ItemCnt := 0 to fItems.Count - 1 do
          begin
             RDXReturn := RDX.hseqSetData(Handle, (ItemCnt + 1), TRDXImage(fItems.Objects[ItemCnt]).Handle);
             if RDXReturn <> ERR_OK then
                ERDXError.Create('Unable to add Bitmap to RDX Bitmap Sequence')
          end;
      end;
end;

procedure TRDXSequence.Delete(aItem: string);
var
   ItemCnt: integer;
   aImage: TRDXImage;
begin
     fItems.Delete(fItems.IndexOf(aItem));

     aImage := TRDXImage(fItems.Objects[0]);

     if fHandle <> nil then
        RDX.hseqDelete(fHandle);

     RDXReturn := RDX.hseqCreate(fItems.Count, aImage.Width, aImage.Height, Integer(aImage.Colors), @Handle);
     if RDXReturn <> ERR_OK then
        ERDXError.Create('Unable to delete Bitmap from RDX Bitmap Sequence')
     else
      begin
         for ItemCnt := 0 to fItems.Count - 1 do
          begin
             RDXReturn := RDX.hseqSetData(Handle, (ItemCnt + 1), TRDXImage(fItems.Objects[ItemCnt]).Handle);
             if RDXReturn <> ERR_OK then
                ERDXError.Create('Unable to delete Bitmap from RDX Bitmap Sequence')
          end;
      end;
end;

function TRDXSequence.Item(aItem: string): TRDXImage;
begin
     Result := TRDXImage(fItems.Objects[fItems.IndexOf(aItem)]);
end;

constructor TRDXBackground.Create(aName: string);
begin
     inherited Create;

     Name := aName;

     RDXReturn := RDX.bkgCreate(@Handle);
     if RDXReturn <> ERR_OK then
        ERDXError.Create('Unable to create RDX Background');
end;

destructor TRDXBackground.Destroy;
begin
     RDXReturn := RDX.bkgDelete(@Handle);
     if RDXReturn <> ERR_OK then
        ERDXError.Create('Unable to destroy RDX Background');

     Handle := nil;
     fImageHandle := nil;

     inherited Destroy;
end;

procedure TRDXBackground.SetImageHandle(aImage: Pointer);
begin
     if aImage <> nil then
      begin
         fImageHandle := aImage;
         RDXReturn := RDX.bkgSetData(Handle, fImageHandle);
         if RDXReturn <> ERR_OK then
            ERDXError.Create('Unable to set Image to RDX Background');
      end;
end;

procedure TRDXBackground.SetHWBlit(aSetting: boolean);
begin
     if aSetting = true then
        RDXReturn := RDX.bkgSetFlags(Handle, 1)
     else
        RDXReturn := RDX.bkgClearFlags(Handle, 1);

     if RDXReturn <> ERR_OK then
        ERDXError.Create('Unable to set RDX HWBLIT for Background');
end;

constructor TRDXSprite.Create(aName: string);
begin
     inherited Create;

     Name := aName;

     RDXReturn := RDX.sprCreate(@Handle);
     if RDXReturn <> ERR_OK then
        ERDXError.Create('Unable to create RDX Sprite');
end;

destructor TRDXSprite.Destroy;
begin
     RDXReturn := RDX.sprDelete(@Handle);
     if RDXReturn <> ERR_OK then
        ERDXError.Create('Unable to destroy RDX Sprite');

     Handle := nil;
     fImageHandle := nil;

     inherited Destroy;
end;

procedure TRDXSprite.SetImageHandle(aImage: Pointer);
begin
     if aImage <> nil then
      begin
         fImageHandle := aImage;
         RDXReturn := RDX.sprSetData(Handle, fImageHandle);
         if RDXReturn <> ERR_OK then
            ERDXError.Create('Unable to set Image to RDX Sprite');
      end;
end;

procedure TRDXSprite.SetHWBlit(aSetting: boolean);
begin
     if aSetting = true then
        RDXReturn := RDX.sprSetFlags(Handle, 1)
     else
        RDXReturn := RDX.sprClearFlags(Handle, 1);

     if RDXReturn <> ERR_OK then
        ERDXError.Create('Unable to set RDX HWBLIT for Sprite');
end;


constructor TRDXSurface.Create(aName: string; aWidth: integer; aHeight: integer; aColors: TRDX_Colors);
begin
     inherited Create;

     fHeight := aHeight;
     fWidth  := aWidth;
     fName   := aName;

     case aColors of
        cl8bit: fColorType := 0;
        cl16bit: fColorType := 2;
        cl24bit: fColorType := 3;
        cl32bit: fColorType := 4;
     else
        fColorType := 0;
     end;

     RDXReturn := RDX.srfCreate(fWidth, fHeight, fColorType, @Handle);
     if RDXReturn <> ERR_OK then
        ERDXError.Create('Unable to create RDX Surface');
end;

destructor TRDXSurface.Destroy;
begin
     RDX.srfDelete(Handle);
     Handle := nil;

     inherited Destroy;
end;

procedure TRDXSurface.SetWindowHandle(aHandle: Hwnd);
begin
     fWindowHandle := aHandle;

     RDXReturn := RDX.srfSetDestWindow(Handle, fWindowHandle);
     if RDXReturn <> ERR_OK then
        ERDXError.Create('Unable to set RDX Surface to Window');
end;

procedure TRDXSurface.SetColorDepth(aColor: TRDX_Colors);
begin
     case aColor of
        cl8bit: fColorType := 0;
        cl16bit: fColorType := 2;
        cl24bit: fColorType := 3;
        cl32bit: fColorType := 4;
     else
        fColorType := 0;
     end;

     RDX.srfDelete(Handle);
     if RDXReturn <> ERR_OK then
        ERDXError.Create('Unable to change Surface Colors');

     Handle := nil;

     RDXReturn := RDX.srfCreate(fWidth, fHeight, fColorType, @Handle);
     if RDXReturn <> ERR_OK then
        ERDXError.Create('Unable to change Surface Colors');

     if fWindowHandle <> 0 then
      begin
         RDXReturn := RDX.srfSetDestWindow(Handle, fWindowHandle);
         if RDXReturn <> ERR_OK then
            ERDXError.Create('Unable to change Surface Colors');
      end;
end;

function TRDXSurface.GetColorDepth: TRDX_Colors;
begin
     case fColorType of
        0: Result := cl8bit;
        2: Result := cl16bit;
        3: Result := cl24bit;
        4: Result := cl32bit;
     else
        Result := cl8bit;
     end;
end;

procedure TRDXSurface.SetHeight(aHeight: integer);
begin
     fHeight := aHeight;

     RDX.srfDelete(Handle);
     if RDXReturn <> ERR_OK then
        ERDXError.Create('Unable to change Height');

     Handle := nil;

     RDXReturn := RDX.srfCreate(fWidth, fHeight, fColorType, @Handle);
     if RDXReturn <> ERR_OK then
        ERDXError.Create('Unable to change Height');

     if fWindowHandle <> 0 then
      begin
         RDXReturn := RDX.srfSetDestWindow(Handle, fWindowHandle);
         if RDXReturn <> ERR_OK then
            ERDXError.Create('Unable to change Height');
      end;
end;

procedure TRDXSurface.Draw;
begin
     RDXReturn := RDX.srfDraw(Handle);
     if RDXReturn <> ERR_OK then
        ERDXError.Create('Unable to Draw RDX Surface');
end;

procedure TRDXSurface.SetWidth(aWidth: integer);
begin
     fWidth := aWidth;

     RDXReturn := RDX.srfDelete(Handle);
     if RDXReturn <> ERR_OK then
        ERDXError.Create('Unable to change Width');

     Handle := nil;

     RDXReturn := RDX.srfCreate(fWidth, fHeight, fColorType, @Handle);
     if RDXReturn <> ERR_OK then
        ERDXError.Create('Unable to change Width');

     if fWindowHandle <> 0 then
      begin
         RDXReturn := RDX.srfSetDestWindow(Handle, fWindowHandle);
         if RDXReturn <> ERR_OK then
            ERDXError.Create('Unable to change Width');
      end;
end;

end.
